@@ -1,5 +1,5 @@
-/* Copyright 2017 - 2024 R. Thomas
- * Copyright 2017 - 2024 Quarkslab
+/* Copyright 2017 - 2025 R. Thomas
+ * Copyright 2017 - 2025 Quarkslab
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -37,7 +37,10 @@ void create<ExportEntry>(nb::module_& m) {
     LIEF_DEFAULT_STR(ExportEntry::forward_information_t);
 
   export_entry
-    .def(nb::init<>())
+    .def(nb::init<>(), "Default constructor"_doc)
+    .def(nb::init<std::string, uint32_t>(),
+         "name"_a, "addr"_a,
+         "Constructor with export name and address"_doc)
 
     .def_prop_rw("name",
         [] (const ExportEntry& obj) {
@@ -74,6 +77,9 @@ void create<ExportEntry>(nb::module_& m) {
       )doc"_doc
     )
 
+    .def("set_forward_info", &ExportEntry::set_forward_info,
+         "lib"_a, "function"_a)
+
     LIEF_DEFAULT_STR(ExportEntry);
 
 }
