@@ -1,5 +1,5 @@
-/* Copyright 2021 - 2023 R. Thomas
- * Copyright 2021 - 2023 Quarkslab
+/* Copyright 2021 - 2025 R. Thomas
+ * Copyright 2021 - 2025 Quarkslab
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -18,23 +18,6 @@
 namespace LIEF {
 namespace PE {
 
-SpcSpOpusInfo::SpcSpOpusInfo() :
-  Attribute(SIG_ATTRIBUTE_TYPES::SPC_SP_OPUS_INFO)
-{}
-
-SpcSpOpusInfo::SpcSpOpusInfo(const SpcSpOpusInfo&) = default;
-SpcSpOpusInfo& SpcSpOpusInfo::operator=(const SpcSpOpusInfo&) = default;
-
-std::unique_ptr<Attribute> SpcSpOpusInfo::clone() const {
-  return std::unique_ptr<Attribute>(new SpcSpOpusInfo{*this});
-}
-
-SpcSpOpusInfo::SpcSpOpusInfo(std::string program_name, std::string more_info) :
-  Attribute(SIG_ATTRIBUTE_TYPES::SPC_SP_OPUS_INFO),
-  program_name_{std::move(program_name)},
-  more_info_{std::move(more_info)}
-{}
-
 void SpcSpOpusInfo::accept(Visitor& visitor) const {
   visitor.visit(*this);
 }
@@ -54,7 +37,5 @@ std::string SpcSpOpusInfo::print() const {
 }
 
 
-SpcSpOpusInfo::~SpcSpOpusInfo() = default;
-
 }
 }
