@@ -6,7 +6,7 @@ from utils import get_sample, is_osx
 
 from .test_builder import run_program
 
-lief.logging.set_level(lief.logging.LOGGING_LEVEL.INFO)
+lief.logging.set_level(lief.logging.LEVEL.INFO)
 
 def test_all(tmp_path):
     bin_path = pathlib.Path(get_sample("MachO/FAT_MachO_x86-x86-64-binary_fatall.bin"))
